Documentation
¶
Overview ¶
Package ros implements functionality that bridges the gap between `rdk` and ROS
Package ros implements functionality that bridges the gap between `rdk` and ROS
Index ¶
- func AllMessagesForTopic(rb *rosbag.RosBag, topic string) ([]map[string]interface{}, error)
- func ReadBag(filename string) (*rosbag.RosBag, error)
- func WriteTopicsJSON(rb *rosbag.RosBag, startTime, endTime int64, topicsFilter []string) error
- type ByteMultiArray
- type ImuData
- type ImuMessage
- type L515Message
- type MessageHeader
- type MultiArrayDimension
- type MultiArrayLayout
- type Quaternion
- type TimeStamp
- type Vector3
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllMessagesForTopic ¶
AllMessagesForTopic returns all messages for a specific topic in the ros bag.
Types ¶
type ByteMultiArray ¶
type ByteMultiArray struct {
Layout MultiArrayLayout
Data []byte
}
ByteMultiArray is a ROS std_msgs/ByteMultiArray message.
type ImuData ¶
type ImuData struct {
Header MessageHeader
Orientation Quaternion
OrientationCovariance [9]int `json:"orientation_covariance"`
AngularVelocity Vector3 `json:"angular_velocity"`
AngularVelocityCovariance [9]int `json:"angular_velocity_covariance"`
LinearAcceleration Vector3 `json:"linear_acceleration"`
LinearAccelerationCovariance [9]int `json:"linear_acceleration_covariance"`
}
ImuData contains the IMU data.
type ImuMessage ¶
ImuMessage reflects the JSON data format for rosbag imu data.
type L515Message ¶
type L515Message struct {
Meta TimeStamp
ColorData ByteMultiArray
DepthData ByteMultiArray
}
L515Message reflects the JSON data format for rosbag Intel Realsense data.
type MessageHeader ¶
MessageHeader is a ROS std_msgs/Header message.
type MultiArrayDimension ¶
MultiArrayDimension is a ROS std_msgs/MultiArrayDimension message.
type MultiArrayLayout ¶
type MultiArrayLayout struct {
Dim []MultiArrayDimension
DataOffset int `json:"data_offset"`
}
MultiArrayLayout is a ROS std_msgs/MultiArrayLayout message.
type Quaternion ¶
Quaternion is a ROS geometry_msgs/Quaternion message.